@@ -70,7 +70,7 @@ struct lookahead_ctx *av1_lookahead_init(
     unsigned int width, unsigned int height, unsigned int subsampling_x,
     unsigned int subsampling_y, int use_highbitdepth, unsigned int depth,
     const int border_in_pixels, int byte_alignment, int num_lap_buffers,
-    bool is_all_intra, int num_pyramid_levels);
+    bool is_all_intra, bool alloc_pyramid);
 
 /**\brief Destroys the lookahead stage
  */
@@ -85,18 +85,18 @@ int av1_lookahead_full(const struct lookahead_ctx *ctx);
  * This function will copy the source image into a new framebuffer with
  * the expected stride/border.
  *
- * \param[in] ctx         Pointer to the lookahead context
- * \param[in] src         Pointer to the image to enqueue
- * \param[in] ts_start    Timestamp for the start of this frame
- * \param[in] ts_end      Timestamp for the end of this frame
- * \param[in] use_highbitdepth Tell if HBD is used
- * \param[in] num_pyramid_levels Number of pyramid levels to allocate
-                          for each frame buffer
- * \param[in] flags       Flags set on this frame
+ * \param[in] ctx               Pointer to the lookahead context
+ * \param[in] src               Pointer to the image to enqueue
+ * \param[in] ts_start          Timestamp for the start of this frame
+ * \param[in] ts_end            Timestamp for the end of this frame
+ * \param[in] use_highbitdepth  Tell if HBD is used
+ * \param[in] alloc_pyramid     Whether to allocate a downsampling pyramid
+ *                              for each frame buffer
+ * \param[in] flags             Flags set on this frame
  */
 int av1_lookahead_push(struct lookahead_ctx *ctx, const YV12_BUFFER_CONFIG *src,
                        int64_t ts_start, int64_t ts_end, int use_highbitdepth,
-                       int num_pyramid_levels, aom_enc_frame_flags_t flags);
+                       bool alloc_pyramid, aom_enc_frame_flags_t flags);
 
 /**\brief Get the next source buffer to encode
  *
