@@ -532,8 +532,10 @@ typedef ::testing::Types<BitDepthParams<uint8_t, 8, false>,   // lowbd
                          BitDepthParams<uint16_t, 10, true>,  // highbd data
                          BitDepthParams<uint16_t, 12, true> >
     AllBitDepthParams;
+// Note the empty final argument can be removed if C++20 is made the minimum
+// requirement.
 INSTANTIATE_TYPED_TEST_SUITE_P(FlatBlockInstatiation, FlatBlockEstimatorTest,
-                               AllBitDepthParams);
+                               AllBitDepthParams, );
 
 template <typename T>
 class NoiseModelUpdateTest : public ::testing::Test, public T {
@@ -968,8 +970,10 @@ REGISTER_TYPED_TEST_SUITE_P(NoiseModelUpdateTest, UpdateFailsNoFlatBlocks,
                             NoiseStrengthChangeSignalsDifferentNoiseType,
                             NoiseCoeffsSignalsDifferentNoiseType);
 
+// Note the empty final argument can be removed if C++20 is made the minimum
+// requirement.
 INSTANTIATE_TYPED_TEST_SUITE_P(NoiseModelUpdateTestInstatiation,
-                               NoiseModelUpdateTest, AllBitDepthParams);
+                               NoiseModelUpdateTest, AllBitDepthParams, );
 
 TEST(NoiseModelGetGrainParameters, TestLagSize) {
   aom_film_grain_t film_grain;
@@ -1368,5 +1372,7 @@ TYPED_TEST_P(WienerDenoiseTest, GradientTest) {
 REGISTER_TYPED_TEST_SUITE_P(WienerDenoiseTest, InvalidBlockSize,
                             InvalidChromaSubsampling, GradientTest);
 
+// Note the empty final argument can be removed if C++20 is made the minimum
+// requirement.
 INSTANTIATE_TYPED_TEST_SUITE_P(WienerDenoiseTestInstatiation, WienerDenoiseTest,
-                               AllBitDepthParams);
+                               AllBitDepthParams, );
